
# Slot: retrieved on




URI: [biolink:retrieved_on](https://w3id.org/biolink/vocab/retrieved_on)


## Domain and Range

[Dataset](Dataset.md) &#8594;  <sub>0..1</sub> [Date](types/Date.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | pav:retrievedOn |

